UpdateModel class

Constructors

UpdateModel({required String id, required String appName, required String version, required String changelog, required String downloadLink, required DateTime createdAt, required int v})
UpdateModel.fromJson(Map<String, dynamic> json)
factory

Properties

appName String
final
changelog String
final
createdAt DateTime
final
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
v int
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited